@@ -21,8 +21,8 @@
 #' }
 incomplete_replace <-
 function(text.var, scan.mode = FALSE) {
-  pat <- "\\?*\\?[.]+|[.?!]*\\? [.][.?!]+|[.?!]*\\. [.?!]+|
-        [.?!]+\\. [.?!]*|[.?!]+\\.[.?!]*|[.?!]*\\.[.?!]+"
+  pat <- paste0("\\?*\\?[.]+|[.?!]*\\? [.][.?!]+|[.?!]*\\. [.?!]+|",
+        "[.?!]+\\. [.?!]*|[.?!]+\\.[.?!]*|[.?!]*\\.[.?!]+")
     if (scan.mode) {
       wid <- options()$width
       options(width = 10000)
