@@ -115,7 +115,8 @@ function(mat, low = "white", high ="darkblue", values = FALSE,
     yaxis.col = "black", order.by = NULL, grid = "white", by.column = TRUE, 
     auto.size = FALSE, mat2 = NULL, plot = TRUE, facet.vars = NULL, 
     facet.flip = FALSE, diag.na = FALSE, diag.values = "", ...) {
-    group <- value <- values2 <- NULL
+    
+    var <- group <- value <- values2 <- NULL
 
     ## set diagonal to NA
     if (diag.na) {
@@ -302,7 +303,8 @@ function(mat, low = "white", high ="darkblue", values = FALSE,
     yaxis.col = "black", order.by = NULL, grid = "white", by.column = TRUE, 
     auto.size = FALSE, mat2 = NULL, plot = TRUE, facet.vars = NULL, 
     facet.flip = FALSE, diag.na = FALSE, diag.values = "", ...) {
-    group <- value <- values2 <- NULL
+    
+    var <- group <- value <- values2 <- NULL
 
     ## set diagonal to NA
     if (diag.na) {
@@ -492,7 +494,8 @@ function(mat, low = "white", high ="darkblue", values = FALSE,
     yaxis.col = "black", order.by = NULL, grid = "white", by.column = TRUE, 
     auto.size = FALSE, mat2 = NULL, plot = TRUE, facet.vars = NULL, 
     facet.flip = FALSE, diag.na = FALSE, diag.values = "", ...) {
-    group <- value <- values2 <- NULL
+    
+    var <- group <- value <- values2 <- NULL
 
     ## set diagonal to NA
     if (diag.na) {
@@ -682,7 +685,8 @@ function(mat, low = "white", high ="darkblue", values = FALSE,
     yaxis.col = "black", order.by = NULL, grid = "white", by.column = TRUE, 
     auto.size = FALSE, mat2 = NULL, plot = TRUE, facet.vars = NULL, 
     facet.flip = FALSE, diag.na = FALSE, diag.values = "", ...) {
-    group <- value <- values2 <- NULL
+    
+    var <- group <- value <- values2 <- NULL
 
     ## set diagonal to NA
     if (diag.na) {
